Changlog for Opevario Compman
=============================

0.6.0 (2021-03-26)
------------------

- Allow to remove a competition, that is no longer in use.


0.5.2 (2020-08-23)
------------------

- Support the newest openvrio-shell.


0.5.1 (2020-07-08)
------------------

- Handle network errors gracefully. Show the error message in case download
  failed.


0.5.0 (2020-07-04)
------------------

- Ability to select / switch competition class for selected competition
- Ability to automatically download and install today's task from soarscore.com


0.4.1 (2020-05-04)
------------------

- Properly expand user directory to find data directory.


0.4 (2020-05-01)
----------------

- Allow to select xcsoar profiles where to install selected competition files.
- Correctly reference waypoint and airspace files in xcsoar profile.
- Integrate with [openvario-shell](https://github.com/kedder/openvario-shell).


0.3 (2020-04-03)
----------------

- Copy competition files to XCSoar home directory. This would allow to backup
  and move xcsoar profile between devices without breaking configuration.


0.2 (2020-03-10)
----------------

- Initial release.
